<div align="center">

![](.media/icon-128x128_round.png)

# Nortrom

Discord bot to mute/deafen entire channels

</div>

## Links

[![Add to server](https://img.shields.io/badge/discord_bot-add-blue)](https://discord.com/oauth2/authorize?client_id=1282746699772727488)

> [!Warning]
> 
> Because of the incredibly little use the bot has seen recently, the bot might have been turned off. Please let me know if you need it!

## Commands

### `/mute`

Requires the _Mute Members_ permission.

Server-mutes all users in the channel you're currently in.

### `/unmute`

Requires the _Mute Members_ permission.

Server-unmutes all users in the channel you're currently in.

### `/deafen`

Requires the _Deafen Members_ permission.

Server-deafen all users in the channel you're currently in.

### `/undeafen`

Requires the _Deafen Members_ permission.

Server-undeafen all users in the channel you're currently in.
